from typing import List

from bluer_ai.host import signature as bluer_ai_signature
from bluer_sbc import fullname as bluer_sbc_fullname

from bluer_ugv import fullname


def signature() -> List[str]:
    return [
        fullname(),
        bluer_sbc_fullname(),
    ] + bluer_ai_signature()



import os

from bluer_objects import file, README

from bluer_ugv import NAME, VERSION, ICON, REPO_NAME


items = README.Items(
    [
        {
            "name": "bluer-beast",
            "marquee": "https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg",
            "description": "based on [UGV Beast PI ROS2](https://www.waveshare.com/wiki/UGV_Beast_PI_ROS2).",
            "url": "./bluer_ugv/docs/bluer-beast.md",
        },
        {
            "name": "bluer-fire",
            "marquee": "https://github.com/kamangir/assets/blob/main/bluer-ugv/bluer-fire.png?raw=true",
            "description": "based on a used car.",
            "url": "./bluer_ugv/docs/bluer-fire.md",
        },
        {
            "name": "bluer-swallow",
            "marquee": "https://github.com/kamangir/assets/blob/main/bluer-ugv/bluer-swallow.png?raw=true",
            "description": "based on power wheels.",
            "url": "./bluer_ugv/docs/bluer-swallow.md",
        },
    ]
)


def build():
    return all(
        README.build(
            items=readme.get("items", []),
            path=os.path.join(file.path(__file__), readme["path"]),
            ICON=ICON,
            NAME=NAME,
            VERSION=VERSION,
            REPO_NAME=REPO_NAME,
        )
        for readme in [
            {
                "items": items,
                "path": "..",
            },
            {"path": "docs/bluer-beast.md"},
            {"path": "docs/bluer-fire.md"},
            {"path": "docs/bluer-swallow.md"},
        ]
    )



NAME = "bluer_ugv"

ICON = "🐬"

DESCRIPTION = f"{ICON} AI x ROS."

VERSION = "6.23.1"

REPO_NAME = "bluer-ugv"

MARQUEE = (
    "https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg"
)

ALIAS = "@ugv"


def fullname() -> str:
    return f"{NAME}-{VERSION}"



from typing import List

from bluer_options.terminal import show_usage, xtra
from bluer_ai.help.generic import help_functions as generic_help_functions

from bluer_ugv import ALIAS


help_functions = generic_help_functions(plugin_name=ALIAS)
